# Changelog

This project adheres to [Semantic Versioning].

## [Unreleased]

## [v3.0.0] - 2020-09-06

No functional changes, only minor refactorings since v2.2.0. Dropping
support for Ruby MRI < 2.4 causes major version bump.

### Added

* Increase test coverage.

### Changed

* Hygienic refactorings: use frozen string literals, prefer squiggly
  heredocs over non-squiggly ones, adhere to the RuboCop linter.

### Removed

* Drop support for Ruby MRI versions below 2.4.

## [v2.2.0] - 2017-03-10

### Added

* Add support for separating asset destination path from the generated
  asset URL. See `render_basename_only` option of `ministamp` tag and
  `destination_baseurl` option of `minibundle` block.

### Changed

* Treat `ministamp` tag's argument as YAML, resulting either in String
  or Hash type of argument after YAML parsing. If argument is of Hash
  type, render values with Liquid-like templating support, allowing
  rendering Liquid variables. This change is backwards compatible.
* Escape the URLs generated by `ministamp` tag and `minibundle` block.
* Quote paths in error messages more consistently.
* Show better error messages in various situations when asset source
  file does not exist.
* Compatibility: conform to Jekyll 3.4.2's StaticFile public API.

## [v2.1.2] - 2017-02-28

### Added

* Show bundle destination path in bundling log message.

### Fixed

* Remove unnecessary '.' path component from asset destination path.
  This manifested when the asset destination had no subdirectory.
  Affects `ministamp` tag and `minibundle` block.

  Example situation:

  ```
  <link href="{{ site.baseurl }}/{% ministamp _assets/site.css site.css %}" rel="stylesheet">
  ```

  Generation result, before the fix:

  ```
  <link href="/./site-6a204bd89f3c8348afd5c77c717a097a.css" rel="stylesheet">
  ```

  Generation result, after the fix:

  ```
  <link href="/site-6a204bd89f3c8348afd5c77c717a097a.css" rel="stylesheet">
  ```
* Related to above: Don't let Jekyll's watch mode (auto-regeneration)
  remove asset from generated site directory when asset destination path
  has no subdirectory.

## [v2.1.1] - 2017-01-14

### Changed

* Compatibility: conform to Jekyll 3.3's StaticFile public API.

### Fixed

* Fix the file permissions of `minibundle` block's output file to
  respect umask setting. Bug report from Alfonse Surigao.

## [v2.1.0] - 2016-05-04

### Changed

* Allow attributes without values. Useful for `async` attribute, for
  example. Pull Request #7 by Sam (@codewisdom).

### Fixed

* Ensure attribute value conversion to string.

## [v2.0.1] - 2016-04-06

### Fixed

* Fix Jekyll version requirement check to be more reliable.

## [v2.0.0] - 2016-04-01

### Changed

* Remove unused asset cache entries and temporary files when Jekyll
  rebuilds the site.
* Document a known caveat: the plugin doesn't work with Jekyll's
  incremental rebuild feature.

### Removed

* Drop support for Jekyll versions below 3.

## [v1.6.0] - 2016-03-26

### Changed

* Log the last 2000 bytes of minifier's STDOUT output if the minifier
  command fails. Pull Request #6 by Martin Nordholts (@Enselic).
* Allow prepending base URL for the destination path of `minibundle`
  block.

### Removed

* Drop Ruby MRI 1.9 support because Jekyll 3 does not support it.

### Fixed

* Fix issues in asset reloading in Jekyll's watch (auto-regeneration)
  mode, doing bundling and asset fingerprinting again.

## [v1.5.1] - 2015-01-29

### Changed

* Improve future compatibility with Jekyll. Minibundle has classes
  adhering to `Jekyll::StaticFile` interface, and some method
  implementations of the interface were missing.
* Small refactorings and test improvements.

## [v1.5.0] - 2014-07-27

### Added

* Support minifier command specification in `_config.yml` and inside
  `minibundle` block. Issue #4 by Phillip Smith (@phillipadsmith).
* Support enabling development mode from `_config.yml`.
* Add argument validation to `minibundle` block and `ministamp` tag.
* Document how to load the gem with Jekyll's `gems` config setting.

## [v1.4.6] - 2014-05-10

### Changed

* Handle compatibility issues with safe_yaml and logger flexibly. This
  should allow using the plugin with Jekyll 1.0 and 2.0.

## [v1.4.5] - 2014-05-10

### Changed

* Use SafeYAML to load user input from `minibundle` block for
  consistent behavior with Jekyll and for security.
* Clean log messages: show relative paths when bundling assets.

### Fixed

* Add missing implementations of `relative_path` and `to_liquid`
  methods from Jekyll's StaticFile API (introduced in Jekyll v1.5.0),
  allowing Minibundle to behave better with other Jekyll
  plugins. Issue #3 by Michael Rose (@mmistakes).
* Fix Ruby deprecation warnings (use `File.exist?` instead of
  `File.exists?`).

## [v1.4.4] - 2014-01-16

### Changed

* Conserve memory when calculating fingerprint for an asset.
  Previously, we read the whole asset file into memory and then
  calculated the MD5 digest. This is bad for big assets. Now, we read
  the file in chunks.

## [v1.4.3] - 2014-01-16

### Changed

* Loosen version constraints for development gem dependencies.
* Clarify documentation.
* Minor internal state handling improvements.
* Clarify tests, increase test coverage.

### Fixed

* Do not leak read pipe file descriptor upon minifier command failure.
* Fix some Ruby coding style issues.

## [v1.4.2] - 2013-12-28

### Changed

* Separate tags produced by `minibundle` in development mode with
  newlines.
* Clarify tests, increase coverage.

### Fixed

* Ensure touching asset source triggers destination write. This was an
  unintentional edge case earlier. Now the behavior of touching the
  asset source is consistent with when changing the contents of the
  source.

## [v1.4.1] - 2013-12-27

### Fixed

* Add missing files to gem package.

## [v1.4.0] - 2013-12-27

### Fixed

* Fix bug causing exception to be thrown when `ministamp` or
  `minibundle` is called twice with same asset source argument. Allow
  handling asset source files that are already static files in Jekyll
  (remove the restriction introduced in 1.3.0). Issue #2 by Austin
  Grigg (@agrigg).

## [v1.3.0] - 2013-12-25

### Changed

* Upgrade development dependencies.

### Fixed

* Disallow handling asset source files that are already static files
  in Jekyll. Otherwise, we would potentially get to inconsistencies in
  Jekyll's watch mode. See "Jekyll static file restriction" in
  README.md. Issue #2 by Austin Grigg (@agrigg).

## [v1.2.0] - 2013-09-29

### Changed

* If Jekyll's logger is available, use it for nice output when bundling.
* Upgrade development dependencies.
* Simplify `BundleFile` class implementation.

## [v1.1.0] - 2013-02-27

### Added

* `ministamp` tag omits fingerprint in development mode.

### Changed

* Clarify documentation.
* Comply with (Gemnasium) conventions for changelogs. Pull Request #1
  by Teemu Matilainen (@tmatilai).

### Fixed

* Don't bundle assets when nonrelated files change.
* Don't bundle assets twice upon startup.

## [v1.0.0] - 2013-02-15

### Added

* Add development mode, where `minibundle` block will copy each asset
  as-is to the destination directory.

### Changed

* Clarify documentation.
* Increase test coverage.

## [v0.2.0] - 2012-12-15

### Added

* Add semicolons between each JavaScript asset in bundling.
* Show error in page output if asset bundling command failed.

### Changed

* Escape the values of custom attributes given in `minibundle` block.

## [v0.1.0] - 2012-12-07

### Added

* Add `ministamp` tag and `minibundle` block for Jekyll.
* First release.

[Semantic Versioning]: https://semver.org/spec/v2.0.0.html
[Unreleased]: https://github.com/tkareine/jekyll-minibundle/compare/v3.0.0...HEAD
[v3.0.0]: https://github.com/tkareine/jekyll-minibundle/compare/v2.2.0...v3.0.0
[v2.2.0]: https://github.com/tkareine/jekyll-minibundle/compare/v2.1.2...v2.2.0
[v2.1.2]: https://github.com/tkareine/jekyll-minibundle/compare/v2.1.1...v2.1.2
[v2.1.1]: https://github.com/tkareine/jekyll-minibundle/compare/v2.1.0...v2.1.1
[v2.1.0]: https://github.com/tkareine/jekyll-minibundle/compare/v2.0.1...v2.1.0
[v2.0.1]: https://github.com/tkareine/jekyll-minibundle/compare/v2.0.0...v2.0.1
[v2.0.0]: https://github.com/tkareine/jekyll-minibundle/compare/v1.6.0...v2.0.0
[v1.6.0]: https://github.com/tkareine/jekyll-minibundle/compare/v1.5.1...v1.6.0
[v1.5.1]: https://github.com/tkareine/jekyll-minibundle/compare/v1.5.0...v1.5.1
[v1.5.0]: https://github.com/tkareine/jekyll-minibundle/compare/v1.4.6...v1.5.0
[v1.4.6]: https://github.com/tkareine/jekyll-minibundle/compare/v1.4.5...v1.4.6
[v1.4.5]: https://github.com/tkareine/jekyll-minibundle/compare/v1.4.4...v1.4.5
[v1.4.4]: https://github.com/tkareine/jekyll-minibundle/compare/v1.4.3...v1.4.4
[v1.4.3]: https://github.com/tkareine/jekyll-minibundle/compare/v1.4.2...v1.4.3
[v1.4.2]: https://github.com/tkareine/jekyll-minibundle/compare/v1.4.1...v1.4.2
[v1.4.1]: https://github.com/tkareine/jekyll-minibundle/compare/v1.4.0...v1.4.1
[v1.4.0]: https://github.com/tkareine/jekyll-minibundle/compare/v1.3.0...v1.4.0
[v1.3.0]: https://github.com/tkareine/jekyll-minibundle/compare/v1.2.0...v1.3.0
[v1.2.0]: https://github.com/tkareine/jekyll-minibundle/compare/v1.1.0...v1.2.0
[v1.1.0]: https://github.com/tkareine/jekyll-minibundle/compare/v1.0.0...v1.1.0
[v1.0.0]: https://github.com/tkareine/jekyll-minibundle/compare/v0.2.0...v1.0.0
[v0.2.0]: https://github.com/tkareine/jekyll-minibundle/compare/v0.1.0...v0.2.0
[v0.1.0]: https://github.com/tkareine/jekyll-minibundle/releases/tag/v0.1.0
